pyxmpp.sasl.core.Failure

Package pyxmpp :: Package sasl :: Module core :: Class Failure |
[hide private]

# Class Failure

source code

    Reply --+
            |
           Failure

The failure SASL message.

Instance Methods | [hide private]
__init__(self, reason) Initialize the Failure object. | source code
__repr__(self) | source code
Inherited from `Reply`: `base64`

Instance Variables | [hide private]
unicode. | reason the failure reason.
Inherited from `Reply`: `data`

Method Details | [hide private]

### __init__(self, reason) (Constructor) | source code
Initialize the Failure object. Parameters: `reason` (unicode.) - the failure reason. Overrides: Reply.__init__